<?php
/**
 * Destination Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add Destination section
$wp_customize->add_section( 'travel_ultimate_pro_destination_section', array(
	'title'             => esc_html__( 'Destination','travel-ultimate-pro' ),
	'description'       => esc_html__( 'Destination Section options.', 'travel-ultimate-pro' ),
	'panel'             => 'travel_ultimate_pro_front_page_panel',
) );

// Destination content enable control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_section_enable]', array(
	'default'			=> 	$options['destination_section_enable'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_ultimate_pro_Switch_Control( $wp_customize, 'travel_ultimate_pro_theme_options[destination_section_enable]', array(
	'label'             => esc_html__( 'Destination Section Enable', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_destination_section',
	'on_off_label' 		=> travel_ultimate_pro_switch_options(),
) ) );

// destination title setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['destination_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[destination_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_destination_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[destination_title]', array(
		'selector'            => '#travel-destinations .section-header h2.section-title',
		'settings'            => 'travel_ultimate_pro_theme_options[destination_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_destination_title_partial',
    ) );
}

// destination description setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['destination_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[destination_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_destination_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_destination_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_ultimate_pro_theme_options[destination_subtitle]', array(
		'selector'            => '#travel-destinations .section-header span.section-subtitle',
		'settings'            => 'travel_ultimate_pro_theme_options[destination_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_ultimate_pro_destination_subtitle_partial',
    ) );
}

// destination description setting and control
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_btn]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['destination_btn'],
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[destination_btn]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-ultimate-pro' ),
	'section'        	=> 'travel_ultimate_pro_destination_section',
	'active_callback' 	=> 'travel_ultimate_pro_is_destination_section_wp_travel',
) );

// destination number control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_count]', array(
	'default'          	=> $options['destination_count'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[destination_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travel-ultimate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_destination_section',
	'active_callback'   => 'travel_ultimate_pro_is_destination_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Destination content type control and setting
$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_content_type]', array(
	'default'          	=> $options['destination_content_type'],
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-ultimate-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-ultimate-pro' ),
		'category' 	=> esc_html__( 'Category', 'travel-ultimate-pro' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-ultimate-pro' );
	$choices['destination'] = esc_html__( 'Destination', 'travel-ultimate-pro' );
}

$wp_customize->add_control( 'travel_ultimate_pro_theme_options[destination_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_ultimate_pro_is_destination_section_enable',
	'choices'			=> $choices,
) );

for ( $i = 1; $i <= $options['destination_count']; $i++ ) :
	// destination pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[destination_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_destination_section',
		'choices'			=> travel_ultimate_pro_page_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_destination_section_content_page_enable',
	) ) );

	// destination posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_ultimate_pro_sanitize_page',
	) );

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[destination_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-ultimate-pro' ), $i ),
		'section'           => 'travel_ultimate_pro_destination_section',
		'choices'			=> travel_ultimate_pro_post_choices(),
		'active_callback'	=> 'travel_ultimate_pro_is_destination_section_content_post_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Chooser( $wp_customize, 'travel_ultimate_pro_theme_options[destination_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-ultimate-pro' ), $i ),
			'section'           => 'travel_ultimate_pro_destination_section',
			'choices'			=> travel_ultimate_pro_trip_choices(),
			'active_callback'	=> 'travel_ultimate_pro_is_destination_section_content_trip_enable',
		) ) );
	}

	// destination hr setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[destination_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new travel_ultimate_pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[destination_hr_'. $i .']',
		array(
			'section'         => 'travel_ultimate_pro_destination_section',
			'active_callback' => 'travel_ultimate_pro_is_destination_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[destination_content_category]', array(
	'sanitize_callback' => 'travel_ultimate_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[destination_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travel-ultimate-pro' ),
	'description'      	=> esc_html__( 'Note: Destination selected no of posts will be shown from selected category', 'travel-ultimate-pro' ),
	'section'           => 'travel_ultimate_pro_destination_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travel_ultimate_pro_is_destination_section_content_category_enable'
) ) );

if ( class_exists( 'WP_Travel' ) ) {
	// Add dropdown destinations setting and control.
	$wp_customize->add_setting(  'travel_ultimate_pro_theme_options[dest_destinations]', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new travel_ultimate_pro_Dropdown_Taxonomies_Control( $wp_customize,'travel_ultimate_pro_theme_options[dest_destinations]', array(
		'label'             => esc_html__( 'Select destinations', 'travel-ultimate-pro' ),
		'description'      	=> esc_html__( 'Note: Selected destination\'s no of posts will be shown from selected category', 'travel-ultimate-pro' ),
		'section'           => 'travel_ultimate_pro_destination_section',
		'type'              => 'dropdown-taxonomies',
		'taxonomy'			=> 'travel_locations',
		'active_callback'	=> 'travel_ultimate_pro_is_dest_destinations_enable'
	) ) );
}